# Integration techniques

## Elementary integrals

$$
\int \frac{1}{a^2 + x^2} dx = \frac{1}{a} \arctan(\frac{x}{a}) + C
$$

$$
\int \frac{1}{\sqrt{a^2-x^2}} dx = \arcsin(\frac{x}{a}) + C
$$

## Linearity of the integral

$$
\int Af(x) + Bg(x)dx = A\int f(x)dx + B\int g(x)dx
$$

**Proof:** is missing.

## Substitution

Suppose that $g$ is a differentiable on $[a,b]$, that satisfies $g(a)=A$ and $g(b)=B$. Also suppose that $f$ is continuous on the range of $g$, then 

let $u = g(x)$ then $du = g'(x)dx$,

$$
\int_a^b f(g(x))g'(x)dx = \int_A^B f(u)du.
$$

## Inverse substitution

Inverse substitutions appear to make the integral more complicated, thereby this strategy must act as last resort. Substituting $x=g(u)$ in the integral

$$
\int_a^b f(x)dx,
$$

leads to the integral

$$
\int_{x=a}^{x=b} f(g(u))g'(u)du.
$$

## Integration by parts

Suppose $U(x)$ and $V(x)$ are two differentiable functions. According to the [product rule](differentation.md/#differentation-rules),

$$
\frac{d}{dx}(U(x)V(x)) = U(x) \frac{dV}{dx} + V(x) \frac{dU}{dx}.
$$

Integrating both sides of this equation and transposing terms

$$
\int U(x) \frac{dV}{dx} dx = U(x)V(x) - \int V(x) \frac{dU}{dx} dx,
$$

obtaining:

$$
\int U dV = U V - \int V dU.
$$

For definite integrals that is:

$$
\int_a^b f'(x)g(x)dx = [f(x)g(x)]_a^b - \int_a^b f(x)g'(x)dx.
$$

## Integration of rational functions

Let $P(x)$ and $Q(x)$ be polynomial functions with real coefficients. Forming a rational function, $\frac{P(x)}{Q(x)}$. Let $\frac{P(x)}{Q(x)}$ be a **strictly proper rational function**, that is; $\mathrm{deg}(P(x)) < \mathrm{deg}(Q(x))$. If the function is not it can be possibly made into a **strictly proper rational function** by using **long division**.

Then, $Q(x)$ can be factored into the product of a constant $K$, real linear factors of the form $x-a_i$, and real quadratic factors of the form $x^2+b_ix + c_i having no real roots.

The rational function can be expressed as a sum of partial fractions. Corresponding to each factor $(x-a)^m$ of $Q(x)$ the decomposition contains a sum of fractions of the form

$$
\frac{A_1}{x-a} + \frac{A_2}{(x-a)^2} + ... + \frac{A_m}{(x-a)^m}.
$$

Corresponding to each factor $(x^2+bx+c)^n$ of $Q(x)$ the decomposition contains a sum of fractions of the form

$$
\frac{B_1x+C_1}{x^2+bx+c} + \frac{B_2x+C_2}{(x^2+bx+c)^2} + ... + \frac{B_nx+C_n}{(x^2+bx+c)^n}. 
$$

The constant $A_1,A_2,...,A_m,B_1,B_2,...,B_n,C_1,C_2,....,C_n$ can be determined by adding up the fractions in the decomposition and equating the coefficients of like powers of $x$ in the numerator of the sum those in $P(x)$.

