# Relations

> *Definition*: a binary relation $R$ between the sets $S$ and $T$ is a subset of the Cartesian product $S \times T$. 
> 
> * If $(a,b) \in R$ then $a$ is in relation $R$ to $b$, denoted by $aRb$.
> * The set $S$ is called the domain of the relation $R$ and the set $T$ the codomain.
> * If $S=T$ then $R$ is a relation on $S$.
> * This definition can be expanded to n-ary relations.

<br>

> *Definition*: let $R$ be a relation from a set $S$ to a set $T$. Then for each element $a \in S$ we define $[a]_R$ to be the set
>
> $$
>   [a]_R := \{b \in T \;|\; aRb\}.
> $$
>
> This set is called the ($R$-) image of $a$. 
>
> For $b \in T$ the set
>
> $$
>   _R[b] := \{a \in S \;|\; aRb\}
> $$
>
> is called the ($R$-) pre-image of $B$ or $R$-fiber of $b$.

<br>

Relations between finite sets can be described using matrices. 

> *Definition*: if $S = \{s_1, \dots, s_n\}$ and $T = \{t_1, \dots, t_m\}$ are finite sets and $R \subseteq S \times T$ is a binary relation, then the adjacency matrix $A_R$ of the relation $R$ is the $n \times n$ matrix whose rows are indexed by $S$ and columns by $T$ defined by
>
> $$
>   A_{s,t} = \begin{cases} 1 &\text{ if } (s,t) \in R, \\ 0 &\text{ otherwise}. \end{cases}
> $$

For example, the adjacency matrix of relation $\leq$ on the set $\{1,2,3,4,5\}$ is the upper triangular matrix

$$
\begin{pmatrix} 1 & 1 & 1 & 1 & 1 \\ 0 & 1 & 1 & 1 & 1 \\ 0 & 0 & 1 & 1 & 1 \\ 0 & 0 & 0 & 1 & 1 \\ 0 & 0 & 0 & 0 & 1\end{pmatrix}
$$

<br>

Some relations have special properties

> *Definitions*: let $R$ be a relation on a set $S$. Then $R$ is called
>
> * *Reflexive* if $\forall x \in S$ there is $(x,x) \in R$.
> * *Irreflexive* if $\forall x \in S$ there is $(x,x) \notin R$.
> * *Symmetric* if $\forall x,y \in S$ there is that $xRy \implies yRx$.
> * *Antisymmetric* if $\forall x,y \in S$ there is that $xRy \land yRx \implies x = y$.
> * *Transitive* if $\forall x,y,z \in S$ there is that $xRy \land yRz \implies xRz$.

## Equivalence relations

> *Definition*: a relation $R$ on a set $S$ is called an equivalence relation on $S$ if and only if it is reflexive, symmetric and transitive.

<br>

> *Lemma*: let $R$ be an equivalence relation on a set $S$. If $b \in [a]_R$, then $[b]_R = [a]_R$.

??? note "*Proof*:"

    Suppose $b \in [a]_R$, therefore $aRb$. If $c \in [b]_R$, then $bRc$ and as $aRb$ there is transitivity $aRc$. In particular $[b]_R \subseteq [a]_R$. By symmetry of $R$, $aRb \implies bRa$ and hence $a \in [b]_R$, obtaining $[a]_R \subseteq [b]_R$. 

<br>

> *Definition*: let $R$ be an equivalence relation on a set $S$. Then the sets $[s]_R$ where $s \in S$ are called the $R$-equivalence classes on $S$. The set of $R$-equivalence classes is denoted by $S/R$.

<br>

> *Theorem*: let $R$ be an equivalence relation on a set $S$. Then the set $S/R$ of $R$-equivalence classes partitions the set $S$. 

??? note "*Proof*:"

    Let $\Pi_R$ be the set of $R$-equivalence classes. Then by reflexivity of $R$ we find that each element $a \in S$ is inside the class $[a]_R$ of $\Pi_R$. If an element $a \in S$ is in the classes $[b]_R$ and $[c]_R$ of $\Pi_R$, then by the previous lemma we find $[b]_R = [a]_R$ and $[c]_R = [a]_R$. Then $[b]_R = [c]_R$, therefore each element $a \in S$ is inside a unique member of $\Pi_R$, which therefore is a partition of $S$.

<br>